SenraisePrinterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SenraisePrinterPlatform
Implementers

Constructors

SenraisePrinterPlatform()
Constructs a SenraisePrinterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getServiceVersion() → Future<String?>
nextLine(int line) → Future<Void?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarCode(String data, int symbology, int height, int width) → Future<Void?>
printEpson(Uint8List bytes) → Future<Void?>
printPic(Uint8List pic) → Future<Void?>
printQRCode(String data, int modulesize, int errorlevel) → Future<Void?>
printText(String text) → Future<Void?>
setAlignment(int alignment) → Future<Void?>
setCode(String code) → Future<Void?>
setDark(int value) → Future<Void?>
setLineHeight(double lineHeight) → Future<Void?>
setTextBold(bool bold) → Future<Void?>
setTextDoubleHeight(bool enable) → Future<Void?>
setTextDoubleWidth(bool enable) → Future<Void?>
setTextSize(double textSize) → Future<Void?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ SenraisePrinterPlatform
The default instance of SenraisePrinterPlatform to use.
getter/setter pair